/******************************************************************************
 * Copyright (c) 2012-2019 All Rights Reserved, http://www.evocortex.com      *
 *  Evocortex GmbH                                                            *
 *  Emilienstr. 1                                                             *
 *  90489 Nuremberg                                                           *
 *  Germany                                                                   *
 *                                                                            *
 * Contributors:                                                              *
 *  Initial version for Linux 64-Bit platform supported by Fraunhofer IPA,    *
 *  http://www.ipa.fraunhofer.de                                              *
 *****************************************************************************/

#pragma once
#include <vector>
#include "IRChannelConfigAI.h"
#include "IRChannelConfigAO.h"
#include "IRChannelConfigDI.h"
#include "IRChannelConfigDO.h"
#include "irdirectsdk_defs.h"

namespace evo {
/**
 * @struct IRPifConfig
 * @brief Config for pif
 * @author Helmut Engelhardt (Evocortex GmbH)
 */

#if _WIN32 && !IRDIRECTSDK_STATIC
  EXPIMP_TEMPLATE template class __IRDIRECTSDK_API__ std::vector<IRChannelConfigDI>;
  EXPIMP_TEMPLATE template class __IRDIRECTSDK_API__ std::vector<IRChannelConfigAI>;
  EXPIMP_TEMPLATE template class __IRDIRECTSDK_API__ std::vector<IRChannelConfigDO>;
  EXPIMP_TEMPLATE template class __IRDIRECTSDK_API__ std::vector<IRChannelConfigAO>;
#endif

struct __IRDIRECTSDK_API__ IRPifConfig
{
  IRPifConfig()
   {
    FlagOpenOutput.AnalogValueOpen = 0;
    FlagOpenOutput.AnalogValueClosed = 0;
    FlagOpenOutput.AnalogValueMoving = 0;
    FrameSyncOutput.AnalogValue = 0;
  }
  
  struct {
    /**
     * @brief Analog Output Voltage/Milliampere when Flag is open
     * 
     */
    float AnalogValueOpen;

    /**
     * @brief Analog Output Voltage/Milliampere when Flag is closed
     * 
     */
    float AnalogValueClosed;
    
    /**
     * @brief Analog Output Voltage/Milliampere when Flag is moving
     * 
     */
    float AnalogValueMoving;

    /**
     * @brief Output channel for flag. On digital true, when flag is open.
     * 
     */
    IRChannelConfig Channel;

  } FlagOpenOutput;

  struct {
    /**
     * @brief Analog Output Voltage/Milliampere on Frame for syncing
     * 
     */
    float AnalogValue;

    /**
     * @brief Output channel for frame sync
     * 
     */
    IRChannelConfig Channel;

  } FrameSyncOutput;


  /**
   * @brief Input channel for set flag state. When input is true, flag should be open.
   * 
   */
  IRChannelConfig FlagOpenInputChannel;

  /**
   * @brief Channel config of digital input channel's
   * 
   */
  std::vector<IRChannelConfigDI> ChannelsDI;

  /**
   * @brief Channel config of analog input channel's
   * 
   */
  std::vector<IRChannelConfigAI> ChannelsAI;

  /**
   * @brief Channel config of digital output channel's
   * 
   */
  std::vector<IRChannelConfigDO> ChannelsDO;

  /**
   * @brief Channel config of analog output channel's
   * 
   */
  std::vector<IRChannelConfigAO> ChannelsAO;
};

}  // namespace evo